@@ -25,7 +25,6 @@
 
 #include "base/files/file_path.h"
 #include "build/build_config.h"
-#include "build/chromeos_buildflags.h"
 #include "util/file/file_io.h"
 
 #if !BUILDFLAG(IS_FUCHSIA)
@@ -44,6 +43,7 @@
 
 #if BUILDFLAG(IS_IOS)
 #include "client/upload_behavior_ios.h"
+#include "handler/user_stream_data_source.h"  // nogncheck
 #endif
 
 namespace crashpad {
@@ -388,6 +388,9 @@ class CrashpadClient {
   //!     Arguments passed in other parameters and arguments required to perform
   //!     the handshake are the responsibility of this method, and must not be
   //!     specified in this parameter.
+  //! \param[in] attachments Attachment paths to pass to the Crashpad handler.
+  //!     The handler will be started with an `--attachment` argument for each
+  //!     path in this vector.
   //!
   //! \return `true` on success, `false` on failure with a message logged.
   bool StartHandlerAtCrash(
@@ -452,7 +455,7 @@ class CrashpadClient {
   //!     FirstChanceHandler and crashes the current process.
   //!
   //! \param[in] message A message to be logged before crashing.
-  static void CrashWithoutDump(const std::string& message);
+  [[noreturn]] static void CrashWithoutDump(const std::string& message);
 
   //! \brief The type for custom handlers installed by clients.
   using FirstChanceHandler = bool (*)(int, siginfo_t*, ucontext_t*);
@@ -548,8 +551,13 @@ class CrashpadClient {
   //! \param[in] annotations Process annotations to set in each crash report.
   //!     Useful when adding crash annotations detected on the next run after a
   //!     crash but before upload.
+  //! \param[in] user_stream_sources An optional vector containing the
+  //!     extensibility data sources to call on crash. Each time a minidump is
+  //!     created, the sources are called in turn. Any streams returned are
+  //!     added to the minidump.
   static void ProcessIntermediateDumps(
-      const std::map<std::string, std::string>& annotations = {});
+      const std::map<std::string, std::string>& annotations = {},
+      const UserStreamDataSources* user_stream_sources = nullptr);
 
   //! \brief Requests that the handler convert a single intermediate dump at \a
   //!     file generated by DumpWithoutCrashAndDeferProcessingAtPath into a
@@ -630,9 +638,10 @@ class CrashpadClient {
   //!     be used in a shipping application.
   static void ResetForTesting();
 
-  //! \brief Inject a callback into Mach handling. Intended to be used by
-  //!     tests to trigger a reentrant exception.
-  static void SetMachExceptionCallbackForTesting(void (*callback)());
+  //! \brief Inject a callback into the Mach exception and signal handling
+  //!     mechanisms. Intended to be used by tests to trigger a reentrant
+  //      exception.
+  static void SetExceptionCallbackForTesting(void (*callback)());
 
   //! \brief Returns the thread id of the Mach exception thread, used by tests.
   static uint64_t GetThreadIdForTesting();
@@ -836,7 +845,7 @@ class CrashpadClient {
   static void UseSystemDefaultHandler();
 #endif
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
   //! \brief Sets a timestamp on the signal handler to be passed on to
   //!     crashpad_handler and then eventually Chrome OS's crash_reporter.
   //!
@@ -861,7 +870,7 @@ class CrashpadClient {
 #endif
 
  private:
-#if BUILDFLAG(IS_WIN)
+#if BUILDFLAG(IS_WIN) || DOXYGEN
   //!  \brief Registers process handlers for the client.
   void RegisterHandlers();
 #endif
