@@ -6,11 +6,11 @@
 
 /**
  * Spawns a new detached subprocess with the given executable and variable
- * arguments as platform native strings terminated by a NULL.
+ * arguments as UTF-8 narrow strings terminated by a NULL.
  *
  * Note: the arguments are not sanitized.
  */
 void sentry__process_spawn(
-    const sentry_path_t *executable, const sentry_pathchar_t *arg0, ...);
+    const sentry_path_t *executable, const char *arg0, ...);
 
 #endif
